#[repr(u8)]pub enum AsianAveragingType {
Arithmetic = 0,
Geometric = 1,
}Expand description
Describes how the average price is calculated for Asian options.
Examples
use option_type::AsianAveragingType;
let avg = AsianAveragingType::Arithmetic;
assert_eq!(format!("{avg}"), "Arithmetic Averaging");Variants
Arithmetic = 0
Arithmetic averaging sums all observed prices and divides by the number of observations.
Geometric = 1
Geometric averaging takes the nth root of the product of n observed prices.
Implementations
Sourceimpl AsianAveragingType
impl AsianAveragingType
Sourcepub const fn is_arithmetic(&self) -> bool
pub const fn is_arithmetic(&self) -> bool
Returns true if this is Arithmetic averaging.
Sourcepub const fn is_geometric(&self) -> bool
pub const fn is_geometric(&self) -> bool
Returns true if this is Geometric averaging.